@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,13 +7,9 @@
 
 #include <QByteArray>
 using namespace NoteShared;
-ShowFolderNotesAttribute::ShowFolderNotesAttribute()
-{
-}
+ShowFolderNotesAttribute::ShowFolderNotesAttribute() = default;
 
-ShowFolderNotesAttribute::~ShowFolderNotesAttribute()
-{
-}
+ShowFolderNotesAttribute::~ShowFolderNotesAttribute() = default;
 
 ShowFolderNotesAttribute *ShowFolderNotesAttribute::clone() const
 {
